/*
 * main.js: 読んだ俳句と日時、場所を記憶するアプリ
 *
 *		v0.9.5	jQuery Mobile1.4.5に最適化
 *		v0.9	俳句データを取り出す機能、関数名修正、不要部分削除
 *		v0.8	俳句リストをクリックすると詠んだ場所を表示する
 *		v0.7	保存した俳句データをリスト表示
 *		v0.6	保存した俳句データの読み込み（とりあえずalertでランダムに表示）
 *		v0.5	GPS情報取得、ローカルストレージに保存する
 */

var haikuData = [];				// 俳句データ
var haikuIndex = null;			// 俳句データのインデックス番号
var screenWidth = null;			// 画面の幅
var screenHeight = null;			// 画面の高さ

/*
 * イベント処理
 */
// ウインドウリサイズ時（幅と高さを再設定）
$(window).on('load resize', function(){
	screenWidth = $(window).width();
	screenHeight = $(window).height();
	
	console.log("w:h = " + screenWidth + ":" + screenHeight);
});
// 各ページが表示されたときの処理
$(document).on("pagecontainershow", function(event, ui){
	// 現在表示されているページID（#xxxx）を取得
	var thisPage = $(":mobile-pagecontainer").pagecontainer("getActivePage").attr("id");
	console.log(thisPage);
	
	if(thisPage == "pgIndex"){			/* トップページ */
		updateHaikuList();
	}
	else if(thisPage == "pgHaikuMap"){	/* 俳句マップページ */
		drawGoogleMap();
	}
	else if(thisPage == "pgInfo"){			/* 情報ページ */
		drawGoogleMap();
	}
	else if(thisPage == "pgEdit"){			/* 修正ページ */
		editHaiku();
	}
});

/*
 * 定数
 */
var MYKEY = "HaikerStorage";		// ローカルストレージ保存キー
var SEP = ",";					// ローカルストレージデータの区切り文字

/*
 * 今日の日時を取得する関数
 */
function getDate(){
	var date = new Date();				// 現在の日付取得

	var year = date.getFullYear();
	var month = date.getMonth() + 1;
	var day = date.getDate();
	var hour = date.getHours();			// 未使用
	var minute = date.getMinutes();			// 未使用
	var seconds = date.getSeconds();		// 未使用
	
	var timeString = year + "-" + month + "-" + day;

	return timeString;
}

/*
 * 今日の一句を別ウインドウで表示する（データが保存されているとき）
 *		未使用		v1.0にて実装予定
 */
function todaysHaiku(){
	if(haikuData != null || haikuData.length != 0){
		// 俳句をランダムで取り出す
		var index = Math.floor(Math.random() * haikuData.length);
		var row = haikuData[index].split(SEP);
		var date = row[0];
		var haiku = date + "\n\n" + row[1] + "\n" + row[2] + "\n" + row[3];
		console.log(haiku);
	}
}

/*
 * 投句ボタンの処理（#pgIndex）
 */
function throwHaiku(){
	var allbody = $("#haiku").val();
	haiku = allbody.split("\n");		// 俳句を取り出す
	// データチェック
	if(allbody == "" || haiku.length < 3) return;		// データがない or 五七五になっていない
	for(var i=0; i<3; i++){						// 五七五が空データかどうか
		if(haiku[i] === "") return;
	}
	
	// 日時取得
	var date = getDate();
	
	// 保存用データ生成
	var savedata = date + SEP + haiku[0] + SEP + haiku[1] + SEP + haiku[2] + SEP + lat + SEP + lng;
	// 日時、俳句、位置情報をローカルストレージに保存する
	haikuData.unshift(savedata);				// 配列の先頭に追加
	var longHaikuData = haikuData.join(SEP);	// 配列haikuDataの要素を全てSEPでつなぎ一つの文字列にする
											// ローカルストレージに一括して保存するため
											
	localStorage.setItem(MYKEY, longHaikuData);	// ローカルストレージに保存
	$("#haiku").val("");						// 入力した俳句をクリア
	/* $("#haiku").focus();					スマートフォンでは使い勝手が悪いためコメントアウト */
	updateHaikuList();						// トップページの俳句リストを更新する
}

/*
 * ローカルストレージの俳句データをチェックする
 */
function checkHaikuStorage(){
	var allbody = localStorage.getItem(MYKEY);
	if(allbody != null && allbody != ""){
		console.log(allbody);
		var columns = allbody.split(SEP);
		console.log("columns.length = " + columns.length);
		for(var i = 0; i<columns.length;i = i + 6){
			var s = columns[i] + SEP + columns[i+1] + SEP + columns[i+2] + SEP + columns[i+3] +SEP + columns[i+4] + SEP + columns[i+5];
			haikuData.push(s);
		}
	}
}

/*
 * トップページの俳句リストを更新する（#pgIndex）
 */
function updateHaikuList(){
	var lists = "";
	// 俳句データが空のとき
	if(haikuData == null || haikuData.length == 0){
		$("#haikuArea").html(lists).trigger("create");
		return;
	}
	
	lists += "<ul data-role='listview'>";
	lists += "<li data-role='list-divider'>句集</li>";
	
	// 俳句データから一句ずつ取り出してリスト表示
	for(var i in haikuData){
		var row = haikuData[i].split(SEP);	// 一行のデータ並び	row[0]～[5] = 日付 , 五 , 七 , 五 , 緯度 , 経度

		var url = "#pgHaikuMap";
		var midashi = "<h2>" + row[1] + "</h2>";
		var haiku = "<p>" + row[2] + "　" + row[3] + "</p>";
		var date = "<p class='ui-li-aside'>" + row[0] + "</p>";

		var list = "<li class='haikulist' haikuIndex='" + i + "'><a href='" + url + "'>" + midashi + haiku + date + "</a></li>";
		lists += list;
	}
	lists += "</ul>";
	// 俳句リストタップ時にインデックス番号を取り出す処理
	lists += "<script>$('li').tap(function(){";
	lists += "haikuIndex = $(this).attr('haikuIndex');";
	lists += "});</script>";

	console.log(lists);
	// コンポーネントの書き換えをjQueryに通知する
	$("#haikuArea").html(lists).trigger("create");
}

/*
 * 修正後の俳句データ保存する（#pgEdit）
 */
function saveUpdatedHaiku(){
	
	var allbody = $("#pasteArea").val();
	if(allbody == null || allbody == "") return;
	// 改行用の文字として「END_LINE」を挿入
	allbody = allbody.replace(/\r/g, "END_LINE");
	allbody = allbody.replace(/\n/g, "END_LINE");
	allbody = allbody.replace(/\r\n/g, "END_LINE");

	// 修正データをローカルストレージに保存する
	haikuData = [];
	
	console.log("haikuData.length = " + haikuData.length);
	var line = allbody.split("END_LINE");	// 一句ごとのデータを配列lineに取得
	console.log("line.length = " + line.length);

	for(var i in line){
		var row = line[i].split(SEP);
		if(row.length == 6){		// 正式なデータのみを配列に追加
			haikuData.push(line[i]);
			console.log("line[" + i + "] = " + line[i]);
		}
	}

	var longHaikuData = haikuData.join(SEP);	// 配列haikuDataの要素を全てSEPでつなぎ一つの文字列にする
											// ローカルストレージに一括して保存するため
											
	localStorage.setItem(MYKEY, longHaikuData);	// ローカルストレージに保存
	alert("俳句データを更新しました");

}

/*
 * 俳句データをダウンロード（パソコンではうまくいくがスマートフォンでは不具合）
 *		未使用
 */
function downloadHaiku(obj){
	var allbody = localStorage.getItem(MYKEY);

	if(allbody != null && allbody != ""){
		var href = "data:application/octet-stream," + encodeURIComponent(allbody);
		obj.setAttribute("href", href);
	}
	else{
		alert("ダウンロードする俳句データはありません");
	}
}

/*
 * 修正ボタンの処理（#pgEdit）
 */
function editHaiku(){
	var line = "";
	// 一句ごとに「END_LINE」で分割
	for(var i in haikuData){
		line += (haikuData[i] + "END_LINE");
	}
	// テキストボックスで改行するために置換
	line = line.replace(/END_LINE/g, "\n");
	// テキストボックスの変更をjQueryに通知（通知しないとテキストボックスのサイズが広がらない）
	$("#pasteArea").val(line).trigger("change");
}

/*
 * 俳句データを全て消去する（#pgIndex）
 */
function longThrowHaiku(){	
	if(haikuData == null || haikuData.length == 0){
		alert("まだ俳句を詠んでいません");
		return;
	}

	var yesNo = confirm("俳句データを全て消去します。よろしいですか？");
	
	if(yesNo == true){
		haikuData = [];
		localStorage.removeItem(MYKEY);
		updateHaikuList();	// トップページの表示を更新
	}
}

/*
 * 起動処理
 */
window.onload = function(){
	// GPS情報チェック
	updateWP();

	// ローカルストレージチェック
	checkHaikuStorage();

	// トップページの俳句リストを更新
	updateHaikuList();
}
